.. :changelog:

History
=======

Version 0.2
-----------

Release 0.2.0
^^^^^^^^^^^^^

`release date: 13 April 2016`

* Adds support for parsing STAR-Fusion hits table output.
* Adds support for parsing STAR alignment log output.
* Adds support for parsing VEP plain text output.


Versions 0.1
------------

Release 0.1.1
^^^^^^^^^^^^^

`release date: 2 February 2016`

* Minor release that loosens the wheel dependency version, updates some
  development dependencies, and fixes some typos.

Release 0.1.0
^^^^^^^^^^^^^

`release date: 27 July 2015`

* First release.
* Support for parsing FastQC, samtools flagstat, and Picard.
